package com.example.application.data.service;

import com.example.application.data.bean.CalculatedMatch;
import com.example.application.data.entity.Game;
import com.example.application.data.entity.Match;
import com.example.application.data.entity.Matchday;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.vaadin.artur.helpers.CrudService;

import java.util.List;
import java.util.stream.Collectors;

@Service
public class MatchService extends CrudService<Match, Integer> {

    private final MatchRepository repository;

    public MatchService(@Autowired MatchRepository repository) {
        this.repository = repository;
    }

    @Override
    protected MatchRepository getRepository() {
        return repository;
    }

    public List<CalculatedMatch> getCalculatedMatches(Matchday matchday) {
        return repository.findAll().stream()
                .filter(match -> match.getMatchday().equals(matchday))
                .map(match -> new CalculatedMatch(match, match.getPlayer1(), match.getPlayer2(), getScore1(match), getScore2(match)))
                .collect(Collectors.toList());
    }

    private static double getScore1(Match match) {
        double score = 0;
        for (Game game : match.getGames()) {
            score += (double) ((game.getPlayer1IsWhite() ? game.getResult() : -game.getResult()) + 1) / 2;
        }
        return score;
    }

    private static double getScore2(Match match) {
        double score = 0;
        for (Game game : match.getGames()) {
            score += (double) ((game.getPlayer1IsWhite() ? -game.getResult() : game.getResult()) + 1) / 2;
        }
        return score;
    }
}
